/**
 * Created by tonyjiang on 16/3/14.
 */
import GeoPlugin from '../interface'
import {ChanjetDecorator} from 'chanjet-plugin-base'

@ChanjetDecorator
class GeoPluginChanjet extends GeoPlugin{

    constructor(){
        super();

        this.pluginName = 'Location';
        this.methodName = {
            getLocation : 'getLocation',
            showLocation : 'showLocation',
            displayNearby : 'displayNearby'
        };
    }

    //获取当前位置
    getLocation(callback = () => {} , requestId = ''){

        cordova.exec(
            this._getLocationSuccessHandler.bind(this , callback , requestId),
            this._getLocationFailedHandler.bind(this , callback , requestId),
            this.pluginName , this.methodName.getLocation , []
        )


    }

    _getLocationSuccessHandler(callback , requestId , rs){
        const rsJSON = JSON.parse(rs);

        const resultCode = rsJSON.code == 0 ? 0 : 1;
        const message = rsJSON.code == 0 ? rsJSON.msg : JSON.parse(rsJSON.msg);

        //获取位置成功后, 将坐标转换成float
        if(resultCode == 0){
            rsJSON.data.latitude = parseFloat(rsJSON.data.latitude);
            rsJSON.data.longitude = parseFloat(rsJSON.data.longitude);
        }

        const result = {
            resultCode : resultCode,
            message : message,
            requestId : requestId,
            body : {
                data : rsJSON.data
            }
        };

        callback(result);
    }

    _getLocationFailedHandler(callback , requestId , error){
        const errorJSON = JSON.parse(error);

        const rs = {
            resultCode : 1,
            message : errorJSON.msg,
            requestId : requestId,
            body : {
                data : errorJSON.data
            }
        };
        callback(rs);
    }

    //在地图上显示位置
    showLocation(options, callback, requestId = ''){
        const {longitude, latitude, location, city, title} = options;

        const params = {
            title : title || '',
            locationInfos : [
                {
                    location: {
                        longitude: longitude,
                        latitude: latitude,
                        location: location,
                        city: city
                    }

                }
            ]
        };

        cordova.exec(
            this._showLocationSuccessHandler.bind(this , callback , requestId),
            this._showLocationFailedHandler.bind(this , callback , requestId),
            this.pluginName , this.methodName.showLocation , [params]
        )
    }

    _showLocationSuccessHandler(callback, requestId, rs){
        const result = {
            resultCode : 0,
            message : 'success',
            requestId : requestId,
            body : {}
        };

        callback(result);
    }

    _showLocationFailedHandler(callback, requestId, rs){
        const result = {
            resultCode : 0,
            message : 'success',
            requestId : requestId,
            body : {}
        };

        callback(result);
    }

    //在地图上选择周边
    displayNearby(options , callback = () => {} , requestId = ''){

        cordova.exec(
            this._displayNearbySuccessHandler.bind(this , callback , requestId),
            this._displayNearbyFailedHandler.bind(this , callback , requestId),
            this.pluginName , this.methodName.displayNearby , [options]
        );

    }

    _displayNearbySuccessHandler(callback , requestId , rs ){
        const rsJSON = JSON.parse(rs);

        const resultCode = rsJSON.code == 0 ? 0 : 1;
        const message = rsJSON.code == 0 ? rsJSON.msg : JSON.parse(rsJSON.msg);

        //获取位置成功后, 将坐标转换成float
        if(resultCode == 0){
            rsJSON.data.latitude = parseFloat(rsJSON.data.latitude);
            rsJSON.data.longitude = parseFloat(rsJSON.data.longitude);
        }

        const result = {
            resultCode : resultCode,
            message : message,
            requestId : requestId,
            body : {
                data : rsJSON.data
            }
        }

        callback(result);
    }

    _displayNearbyFailedHandler(callback , requestId , error ){
        const errorJSON = JSON.parse(error);

        const rs = {
            resultCode : 1,
            message : errorJSON.msg,
            requestId : requestId,
            body : {
                data : errorJSON.data
            }
        };
        callback(rs);
    }

}

export default GeoPluginChanjet